@@ -7,11 +7,11 @@ from seti_python.class_read import (
     ResponseReadWallet,
     ResponseReadWalletsTransactions,
 )
-from seti_python.class_users import ResponseCreateUser, ResponseValidateUsersExist
+from seti_python.class_users import ResponseCreateCustomToken, ResponseCreateUser, ResponseValidateUsersExist
 from seti_python.wallet_class import ResponseCreateWallet
 from seti_python.class_tools import (
     BasicResponse,
-    CompleteBasicaResponse,
+    CompleteBasicResponse,
     ResponseCreateDispersions,
     ResponseCreateTransaction,
 )
@@ -53,13 +53,14 @@ class Seti:
         """
         if self.public_key_loc == "":
             raise MyException({"msg": "Provide public key path", "code": 1})
-        buffered_data = execjs.eval("Buffer.from(JSON.stringify({}))".format(data))
-        bytesData = bytearray(buffered_data["data"])
+        buffered_data = execjs.eval(
+            "Buffer.from(JSON.stringify({}))".format(data))
+        bytes_data = bytearray(buffered_data["data"])
         pub_key = open(self.public_key_loc, "r").read()
         rsakey = RSA.importKey(pub_key)
         signer = PKCS1_v1_5.new(rsakey)
         digest = SHA256.new()
-        digest.update(bytesData)
+        digest.update(bytes_data)
         if signer.verify(digest, b64decode(signature)):
             return True
         return False
@@ -71,12 +72,12 @@ class Seti:
         param: passphrase  api key
         return: Sign data provide
         """
-        buffered_data = execjs.eval("Buffer.from(JSON.stringify({}))".format(data))
-        bytesData = bytearray(buffered_data["data"])
+        buffered_data = execjs.eval(
+            "Buffer.from(JSON.stringify({}))".format(data))
+        bytes_data = bytearray(buffered_data["data"])
         rsakey = RSA.importKey(self.private_key)
-        hash = SHA256.new(bytesData)
         cipher_rsa = PKCS1_v1_5.new(rsakey)
-        return b64encode(cipher_rsa.sign(hash)).decode("utf-8")
+        return b64encode(cipher_rsa.sign(SHA256.new(bytes_data))).decode("utf-8")
 
     def send_request(self, data: dict, sign_data: str, path: str):
         try:
@@ -142,7 +143,8 @@ class Seti:
         CREATE_PAYMENT_URL = "create-payment"
         encode_data = self.sign_data(data_create_payment)
         return ResponseCreatePayment(
-            self.send_request(data_create_payment, encode_data, CREATE_PAYMENT_URL)
+            self.send_request(data_create_payment,
+                              encode_data, CREATE_PAYMENT_URL)
         )
 
     # Wallets
@@ -159,7 +161,8 @@ class Seti:
         CREATE_WALLET_URL = "create-wallet"
         encode_data = self.sign_data(data_create_wallet)
         return ResponseCreateWallet(
-            self.send_request(data_create_wallet, encode_data, CREATE_WALLET_URL)
+            self.send_request(data_create_wallet,
+                              encode_data, CREATE_WALLET_URL)
         )
 
     def validate_wallet(self, code: str, secret: str):
@@ -169,8 +172,9 @@ class Seti:
         }
         VALIDATE_WALLET_URL = "validate-wallet"
         encode_data = self.sign_data(data_validate_wallet)
-        return CompleteBasicaResponse(
-            self.send_request(data_validate_wallet, encode_data, VALIDATE_WALLET_URL)
+        return CompleteBasicResponse(
+            self.send_request(data_validate_wallet,
+                              encode_data, VALIDATE_WALLET_URL)
         )
 
     def read_wallet_data(self, secret: str):
@@ -208,7 +212,8 @@ class Seti:
         SEND_MONEY_WALLETS_URL = "send-money-between-wallets"
         encode_data = self.sign_data(data_send_money)
         return ResponseCreateTransaction(
-            self.send_request(data_send_money, encode_data, SEND_MONEY_WALLETS_URL)
+            self.send_request(data_send_money, encode_data,
+                              SEND_MONEY_WALLETS_URL)
         )
 
     def retention_money(self, from_secret: str, value: int):
@@ -217,7 +222,8 @@ class Seti:
         RETENTION_MONEY_URL = "retention-money"
         encode_data = self.sign_data(data_retention_money)
         return ResponseCreateTransaction(
-            self.send_request(data_retention_money, encode_data, RETENTION_MONEY_URL)
+            self.send_request(data_retention_money,
+                              encode_data, RETENTION_MONEY_URL)
         )
 
     # Reversal
@@ -227,7 +233,8 @@ class Seti:
         REVERSAL_PAYMENT_URL = "reversal-payment"
         encode_data = self.sign_data(data_send_money)
         return ResponseCreateTransaction(
-            self.send_request(data_send_money, encode_data, REVERSAL_PAYMENT_URL)
+            self.send_request(data_send_money, encode_data,
+                              REVERSAL_PAYMENT_URL)
         )
 
     # Recharger
@@ -247,7 +254,8 @@ class Seti:
         CREATE_RECHARGER_URL = "create-recharger"
         encode_data = self.sign_data(data_create_recharger)
         return ResponseCreatePayment(
-            self.send_request(data_create_recharger, encode_data, CREATE_RECHARGER_URL)
+            self.send_request(data_create_recharger,
+                              encode_data, CREATE_RECHARGER_URL)
         )
 
     # Dispersion
@@ -313,7 +321,8 @@ class Seti:
         READ_TOTAL_CASH_OUT_URL = "read-total-cashout"
         encode_data = self.sign_data(data_read_cash)
         return ResponseReadCashOut(
-            self.send_request(data_read_cash, encode_data, READ_TOTAL_CASH_OUT_URL)
+            self.send_request(data_read_cash, encode_data,
+                              READ_TOTAL_CASH_OUT_URL)
         )
 
     def read_transactions(self):
@@ -322,7 +331,8 @@ class Seti:
         READ_TRANSACTIONS_URL = "read-transactions"
         encode_data = self.sign_data(data_read_cash)
         return ResponseReadTransactions(
-            self.send_request(data_read_cash, encode_data, READ_TRANSACTIONS_URL)
+            self.send_request(data_read_cash, encode_data,
+                              READ_TRANSACTIONS_URL)
         )
 
     def create_user(self, email: str, first_name: str, phone: str, iso_code: str):
@@ -336,7 +346,6 @@ class Seti:
         }
         CREATE_USER_URL = "create-user"
         encode_data = self.sign_data(data_read_cash)
-        print(encode_data)
         return ResponseCreateUser(
             self.send_request(data_read_cash, encode_data, CREATE_USER_URL)
         )
@@ -345,37 +354,48 @@ class Seti:
         self.is_error = False
         self.validate_email(email)
         data_read_cash = {"email": email}
-        CREATE_USER_URL = "validate-user"
+        VALIDATE_EXIST_URL = "validate-user"
         encode_data = self.sign_data(data_read_cash)
         return ResponseValidateUsersExist(
-            self.send_request(data_read_cash, encode_data, CREATE_USER_URL)
+            self.send_request(data_read_cash, encode_data, VALIDATE_EXIST_URL)
         )
 
     def create_associated_wallet(self, iso_code: str):
         self.is_error = False
         create_wallet = {"isoCode": iso_code}
-        CREATE_ASSOCIATED_WALLET = "create-associated-wallet"
+        CREATE_ASSOCIATED_WALLET_URL = "create-associated-wallet"
         encode_data = self.sign_data(create_wallet)
         return ResponseCreateWallet(
-            self.send_request(create_wallet, encode_data, CREATE_ASSOCIATED_WALLET)
+            self.send_request(create_wallet, encode_data,
+                              CREATE_ASSOCIATED_WALLET_URL)
         )
 
-
-    def revert_transaction(self,transaction_id:str):
+    def revert_transaction(self, transaction_id: str):
         self.is_error = False
         data_read_cash = {"transactionId": transaction_id}
         REVERT_TRANSACTION_URL = "reverse-transaction"
         encode_data = self.sign_data(data_read_cash)
-        return CompleteBasicaResponse(
-            self.send_request(data_read_cash, encode_data, REVERT_TRANSACTION_URL)
+        return CompleteBasicResponse(
+            self.send_request(data_read_cash, encode_data,
+                              REVERT_TRANSACTION_URL)
         )
 
-
-    def read_single_transaction(self,transaction_id:str):
+    def read_single_transaction(self, transaction_id: str):
         self.is_error = False
         data_read_cash = {"transactionId": transaction_id}
-        REVERT_TRANSACTION_URL = "read-transaction"
+        READ_SINGLED_TRANSACTION_URL = "read-transaction"
         encode_data = self.sign_data(data_read_cash)
         return ResponseReadSingleTransactions(
-            self.send_request(data_read_cash, encode_data, REVERT_TRANSACTION_URL)
+            self.send_request(data_read_cash, encode_data,
+                              READ_SINGLED_TRANSACTION_URL)
+        )
+
+    def create_user_custom_token(self, secret: str):
+        self.is_error = False
+        data_read_cash = {"secret": secret}
+        CREATE_CUSTOMER_TOKEN_URL = "create-custom-token"
+        encode_data = self.sign_data(data_read_cash)
+        return ResponseCreateCustomToken(
+            self.send_request(data_read_cash, encode_data,
+                              CREATE_CUSTOMER_TOKEN_URL)
         )
