@@ -136,7 +136,7 @@ class ResponseReadCashOut(BasicResponse):
 
 class Transaction:
     currency_id: str
-    from_nusiness_id: str
+    from_business_id: str
     cash_out_id: str
     value: float
     to_wallet_id: str
@@ -144,7 +144,7 @@ class Transaction:
     timestamp: dict
     to_business_id: str
     payment_id: str
-    transaction_iype: str
+    transaction_type: str
     id: str
     convert_value: float
     conversion_rate: float
@@ -162,7 +162,7 @@ class Transaction:
         self.convert_value = data["convertValue"]
         if "toBusinessId" in data:
             self.to_business_id = data["toBusinessId"]
-            self.from_nusiness_id = data["fromBusinessId"]
+            self.from_business_id = data["fromBusinessId"]
         if "id" in data:
             self.id = data["id"]
 
@@ -194,10 +194,11 @@ class ResponseReadSingleTransactions(BasicResponse):
     def __init__(self, data: dict):
         self.msg = data['msg']
         self.res = data['res']
+        print(data)
         if data['res'] == 200:
             self.data = Transaction(data['data'])
         else:
-            self.data = Transaction({})
+            self.data = {}
 
 # Read Wallet
 
