@@ -35,6 +35,8 @@ class NewUsers:
 
     def __repr__(self):
         return str(self.__dict__)
+
+
 class ResponseCreateUser(BasicResponse):
     data: NewUsers
 
@@ -45,3 +47,28 @@ class ResponseCreateUser(BasicResponse):
             self.data = NewUsers(data['data'])
         else:
             self.data = NewUsers({})
+
+
+class CustomToken:
+    token: str
+
+    def __init__(self, data: dict):
+        try:
+            self.customToken = data['customToken']
+        except Exception:
+            self.customToken = ""
+
+    def __repr__(self):
+        return str(self.__dict__)
+
+
+class ResponseCreateCustomToken(BasicResponse):
+    data: str
+
+    def __init__(self, data: dict):
+        self.msg = data['msg']
+        self.res = data['res']
+        if data['res'] == 200:
+            self.data = CustomToken(data['data'])
+        else:
+            self.data = CustomToken("")
