@@ -12,13 +12,14 @@ class ResponseCreatePaymentData:
         except Exception:
             return
 
+    def __repr__(self):
+        return str(self.__dict__)
+
 
 class ResponseCreatePayment(BasicResponse):
     data: ResponseCreatePaymentData
 
     def __init__(self, data: dict):
-        print("----------------------------------")
-        print(data)
         self.msg = data["msg"]
         self.res = data["res"]
         if data["res"] == 200:
